===========
Calorimeter
===========


.. image:: https://img.shields.io/travis/jevandezande/calorimeter/master.svg
        :target: https://travis-ci.org/jevandezande/calorimeter


Package for manipulting and plotting data from a differential scanning calorimeter.


* Free software: MIT license


Features
--------

* TODO
